==> fontutils-0.6.tar.gz: fontutils-0.6/xbfe/commands.h <==
/* commands.h: declarations for the operations.

Copyright (C) 1992 Free Software Foundation, Inc.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef COMMANDS_H
#define COMMANDS_H

#include "xt-common.h"


/* Where the output goes.  */
extern string output_name;

/* Exit the program, first closing FONT_NAME.  */
extern void exit_command (Widget, XtPointer font_name, XtPointer);

/* Go to the next, previous, current, or specified character in FONT.  */
extern void next_command (Widget, XtPointer font, XtPointer);
extern void prev_command (Widget, XtPointer font, XtPointer);
extern void revert_command (Widget, XtPointer font, XtPointer);
extern void char_change_callback (Widget, XtPointer font, XtPointer charcode);

/* Change the side bearing values for the current character in FONT to
   VALUE.  */ 
extern void lsb_change_callback (Widget, XtPointer font, XtPointer value);
extern void rsb_change_callback (Widget, XtPointer font, XtPointer value);

/* Expand the bitmap by one pixel in all dimensions.  */
extern void expand_command (Widget, XtPointer font, XtPointer);

/* Write the current font, passed as FONT, to disk.  */
extern void save_command (Widget, XtPointer font, XtPointer);

#endif /* not COMMANDS_H */

==> fontutils-0.7.tar.gz: fontutils-0.7/xbfe/commands.h <==
/* commands.h: declarations for the operations.

Copyright (C) 1992 Free Software Foundation, Inc.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef COMMANDS_H
#define COMMANDS_H

#include "xt-common.h"


/* Where the output goes.  */
extern string output_name;

/* Exit the program, first closing FONT_NAME.  */
extern void exit_command (Widget, XtPointer font_name, XtPointer);

/* Go to the next, previous, current, or specified character in FONT.  */
extern void next_command (Widget, XtPointer font, XtPointer);
extern void prev_command (Widget, XtPointer font, XtPointer);
extern void revert_command (Widget, XtPointer font, XtPointer);
extern void char_change_callback (Widget, XtPointer font, XtPointer charcode);

/* Change the side bearing values for the current character in FONT to
   VALUE.  */ 
extern void lsb_change_callback (Widget, XtPointer font, XtPointer value);
extern void rsb_change_callback (Widget, XtPointer font, XtPointer value);

/* Expand the bitmap by one pixel in all dimensions.  */
extern void expand_command (Widget, XtPointer font, XtPointer);

/* Write the current font, passed as FONT, to disk.  */
extern void save_command (Widget, XtPointer font, XtPointer);

#endif /* not COMMANDS_H */
